==> nsc-2.0.8-140-GA.update.tgz: var/webconfig/NSC_modules/application/libraries/nsc_rtcpmon_service_class.php <==
<?php
/** vim: set tabstop=4 softtabstop=4 shiftwidth=4 textwidth=80 smarttab expandtab: **/
/** coding: utf-8: **/
/*
 * Copyright (C) 2012  Sangoma Technologies Corp.
 * All Rights Reserved.
 *
 * Author(s)
 * your name <your_name@sangoma.com>
 *
 * This code is Sangoma Technologies Confidential Property.
 * Use of and access to this code is covered by a previously executed
 * non-disclosure agreement between Sangoma Technologies and the Recipient.
 * This code is being supplied for evaluation purposes only and is not to be
 * used for any other purpose.
*/
/**
 * NSC RTCP Monitor Service Class
 * @author Shaunt Libarian
 */
require_once ('application/helpers/safe_helper.php');
safe_require_class('safe_service_class');
safe_require_class('safe_db_class');
safe_module_require_class('nsc', 'product');
safe_module_require_class('nsc', 'application');
safe_module_require_class('nsc', 'rtcpmon_config');
class Nsc_rtcpmon_service_class extends Safe_service_class
{
    private $name = 'rtcpmon';
    private $_node = "";
    function __construct($node, $software)
    {
        parent::__construct($software, 'rtcpmon');
        $this->_node = $node;
    }
    //Information pulled for the object
    public function configure()
    {
        // Create the object
        $cfg = new Nsc_rtcpmon_config_class($this->_node, parent::path() , $this->name());
        // Create the fields
        $cfg->configure();
        // Synchronize with persistent DB (safe_object table)
        $cfg->synch();
        // Register config to service
        $this->set_config($cfg);
        // Set service description
        $this->set_description('RTCP Monitor');
        return parent::configure();
    }
    function db()
    {
        $tmp_db_cfg = $this->config()->get_data_values_exploded();
        // Filter out db-cfg
        $cfg_db = $tmp_db_cfg['db-cfg'];
        //will return the array needed to create the db connection (key=>value)
        $db = Safe_database_class::factory($cfg_db);
        return $db;
    }
    public function support_reload(&$need_reload = null) {
        parent::support_reload($need_reload);
        return true;
    }   
    public function reload_generate_config(&$config_manager, $obj_type=null)
    {   
        if(!$this->generate_config($config_manager)) return false;
        return parent::reload_generate_config($config_manager, $obj_type);
    }   
    public function reload_clear_modified($obj_type=null)
    {
        $this->config()->clear_modified();
    }
    public function post_write_config()
    {
        if(Safe_service_class::STATUS_RUNNING == $this->status()){
            $this->restart();
        }
    }
    /**
     * @brief Generate RTCPMON configuration
     *           
     * @param[in out] $config_manager
     *           
     * @return true on success
     */
    public function generate_config(&$config_manager)
    {
        // Get our configuration data (unresolved)
        $cfg = $this->config()->get_data_values_exploded(false);
        // Remove global config - Used by service control script (application)
        unset($cfg['global']);
        // Create xml document
        $xml_writer = new XMLWriter();
        $xml_writer->openMemory();
        $xml_writer->startDocument('1.0', 'UTF-8');
        // Document container
        $xml_writer->startElement('document');
        $xml_writer->writeAttribute('type', 'rtcpmon/xml');
        // Process database configuration
        $xml_writer->startElement('database');
        // Create connection-sting
        // <param name="connection-string"
        // value="DRIVER={MySQL};DATABASE=nsc;server=localhost;user=root;pwd=sangoma;port=3306"/>
        $connection_string = 'DRIVER={' . $cfg['db-cfg']['dbdriver'] . '};' . 'DATABASE=' . $cfg['db-cfg']['database'] . ';' . 'server=' . $cfg['db-cfg']['hostname'] . ';' . 'user=' . $cfg['db-cfg']['username'] . ';' . 'pwd=' . $cfg['db-cfg']['password'] . ';' . 'port=' . $cfg['db-cfg']['port'] . ';';
        $xml_writer->startElement('param');
        $xml_writer->writeAttribute('name', 'connection-string');
        $xml_writer->writeAttribute('value', $connection_string);
        $xml_writer->fullEndElement();
        foreach ($cfg['database'] as $k => $v) {
            $xml_writer->startElement('param');
            $xml_writer->writeAttribute('name', $k);
            $xml_writer->writeAttribute('value', $v);
            $xml_writer->fullEndElement();
        }
        // Remove database config entries
        $xml_writer->fullEndElement();
        unset($cfg['database']);
        unset($cfg['db-cfg']);
        // Add all parameters
        foreach ($cfg as $category => $cat_cfg) {
            $xml_writer->startElement($category);
            foreach ($cat_cfg as $k => $v) {
                $xml_writer->startElement('param');
                $xml_writer->writeAttribute('name', $k);
                $xml_writer->writeAttribute('value', $v);
                $xml_writer->fullEndElement();
            }
            $xml_writer->fullEndElement();
        }
        // Close settings
        $xml_writer->fullEndElement();
        $xml_writer->endDocument();
        $xmlstr = Safe_format_xml($xml_writer->outputMemory(true));
        $file = $config_manager->directory('base') . '/etc/' . $this->name() . '.xml';
        $config_manager->add_config(new Safe_configuration_class($file, $xmlstr));
        return parent::generate_config($config_manager);
    }
    public function category()
    {
        return 'Media';
    }
    /**
     * @brief
     *         
     * @return
     */
    public function get_data_settings()
    {
        $cfg_manager = $this->node()->configuration_manager();
        $data = array(
            'log' => array(
                'description' => 'Log file',
                'filesystem' => true,
                'pattern' => '/var/log/' . $this->name() . '.log*',
                'global_capabilities' => array(
                    'download'
                ) ,
                'capabilities' => array(
                    'download',
                    'view'
                ) ,
            )
        );
        return $data;
    }
}

==> nsc-2.1.6-43-GA.update.tgz: var/webconfig/NSC_modules/application/libraries/nsc_rtcpmon_service_class.php <==
<?php
/** vim: set tabstop=4 softtabstop=4 shiftwidth=4 textwidth=80 smarttab expandtab: **/
/** coding: utf-8: **/
/*
 * Copyright (C) 2012  Sangoma Technologies Corp.
 * All Rights Reserved.
 *
 * Author(s)
 * your name <your_name@sangoma.com>
 *
 * This code is Sangoma Technologies Confidential Property.
 * Use of and access to this code is covered by a previously executed
 * non-disclosure agreement between Sangoma Technologies and the Recipient.
 * This code is being supplied for evaluation purposes only and is not to be
 * used for any other purpose.
*/
/**
 * NSC RTCP Monitor Service Class
 * @author Shaunt Libarian
 */
require_once ('application/helpers/safe_helper.php');
safe_require_class('safe_service_class');
safe_require_class('safe_db_class');
safe_module_require_class('nsc', 'product');
safe_module_require_class('nsc', 'application');
safe_module_require_class('nsc', 'rtcpmon_config');


class Nsc_rtcpmon_service_class extends Safe_service_class
{
    private $name = 'rtcpmon';
    private $_node = "";
    function __construct($node, $software)
    {
        parent::__construct($software, 'rtcpmon');
        $this->_node = $node;
    }
    //Information pulled for the object
    public function configure()
    {
        // Create the object
        $cfg = new Nsc_rtcpmon_config_class($this->_node, $this->object_name() , $this->name());
        // Create the fields
        $cfg->configure();
        // Synchronize with persistent DB (safe_object table)
        $cfg->synch();
        // Register config to service
        $this->set_config($cfg);
        // Set service description
        $this->set_description('RTCP Monitor');
        return parent::configure();
    }
    function db()
    {
        $tmp_db_cfg = $this->config()->get_data_values_exploded();
        // Filter out db-cfg
        $cfg_db = $tmp_db_cfg['db-cfg'];
        //will return the array needed to create the db connection (key=>value)
        $db = Safe_database_class::factory($cfg_db);
        return $db;
    }
    public function support_reload(&$need_reload = null) {
        parent::support_reload($need_reload);
        return true;
    }   
    public function reload_generate_config(&$config_manager, $obj_type=null)
    {   
        if(!$this->generate_config($config_manager)) return false;
        return parent::reload_generate_config($config_manager, $obj_type);
    }   
    public function reload_clear_modified($obj_type=null)
    {
        $this->config()->clear_modified();
    }
    public function post_write_config()
    {
        if(Safe_service_class::STATUS_RUNNING == $this->status()){
            $this->restart();
        }
    }
    /**
     * @brief Generate RTCPMON configuration
     *           
     * @param[in out] $config_manager
     *           
     * @return true on success
     */
    public function generate_config(&$config_manager)
    {
        // Get our configuration data (unresolved)
        $cfg = $this->config()->get_data_values_exploded(false);
        // Remove global config - Used by service control script (application)
        unset($cfg['global']);
        // Create xml document
        $xml_writer = new XMLWriter();
        $xml_writer->openMemory();
        $xml_writer->startDocument('1.0', 'UTF-8');
        // Document container
        $xml_writer->startElement('document');
        $xml_writer->writeAttribute('type', 'rtcpmon/xml');
        // Process database configuration
        $xml_writer->startElement('database');
        // Create connection-sting
        // <param name="connection-string"
        // value="DRIVER={MySQL};DATABASE=nsc;server=localhost;user=root;pwd=sangoma;port=3306"/>
        $connection_string = 'DRIVER={' . $cfg['db-cfg']['dbdriver'] . '};' . 'DATABASE=' . $cfg['db-cfg']['database'] . ';' . 'server=' . $cfg['db-cfg']['hostname'] . ';' . 'user=' . $cfg['db-cfg']['username'] . ';' . 'pwd=' . $cfg['db-cfg']['password'] . ';' . 'port=' . $cfg['db-cfg']['port'] . ';';
        $xml_writer->startElement('param');
        $xml_writer->writeAttribute('name', 'connection-string');
        $xml_writer->writeAttribute('value', $connection_string);
        $xml_writer->fullEndElement();
        foreach ($cfg['database'] as $k => $v) {
            $xml_writer->startElement('param');
            $xml_writer->writeAttribute('name', $k);
            $xml_writer->writeAttribute('value', $v);
            $xml_writer->fullEndElement();
        }
        // Remove database config entries
        $xml_writer->fullEndElement();
        unset($cfg['database']);
        unset($cfg['db-cfg']);
        // Add all parameters
        foreach ($cfg as $category => $cat_cfg) {
            $xml_writer->startElement($category);
            foreach ($cat_cfg as $k => $v) {
                $xml_writer->startElement('param');
                $xml_writer->writeAttribute('name', $k);
                $xml_writer->writeAttribute('value', $v);
                $xml_writer->fullEndElement();
            }
            $xml_writer->fullEndElement();
        }
        // Close settings
        $xml_writer->fullEndElement();
        $xml_writer->endDocument();
        $xmlstr = Safe_format_xml($xml_writer->outputMemory(true));
        $file = $config_manager->directory('base') . '/etc/' . $this->name() . '.xml';
        $config_manager->add_config(new Safe_configuration_class($file, $xmlstr));
        return parent::generate_config($config_manager);
    }
    public function category()
    {
        return 'Media';
    }
    /**
     * @brief
     *         
     * @return
     */
    public function get_data_settings()
    {
        $cfg_manager = $this->node()->configuration_manager();
        $data = array(
            'log' => array(
                'description' => 'Log file',
                'filesystem' => true,
                'pattern' => '/var/log/' . $this->name() . '.log*',
                'global_capabilities' => array(
                    'download'
                ) ,
                'capabilities' => array(
                    'download',
                    'view'
                ) ,
                'methods' => array(
                        'download' => array(
                                'name' => 'Download',
                                'description' => array( 'Download log files.' ),
                                'request' => 'GET',
                        )
                )
            )
        );
        return $data;
    }
    public function api_download_log($name=null, $data = null, &$output = null){
        $this->download_data('log', $name);
        exit();
    }
    public function pid_file()
    {
        $cfg_mgr = $this->node()->configuration_manager();
        $base_dir = $cfg_mgr->directory('base');
        return $base_dir.'/run/'.$this->name().'.pid';
    }
    public function can_restore($info, &$reason)
    {
        return true;
    }
    public function allow_dashboard()
    {
        $transcoding = new Sng_transcoding_config_class($this->_node);
        $transcoding->configure();
        // No RTCPMON when transcoding disabled
        if (!$transcoding->is_enabled()){
            return false;
        }
        return parent::allow_dashboard();
    }
    public function allow_user_ctl()
    {
        $transcoding = new Sng_transcoding_config_class($this->_node);
        $transcoding->configure();
        // No RTCPMON when transcoding disabled
        if (!$transcoding->is_enabled()){
            return 'hide';
        }
        return parent::allow_user_ctl();
    }
}
